<?php

namespace App\Controllers\Admin;

use App\Controllers\BaseController;
use App\Models\Staffs;
use App\Models\Staf;
use App\Models\Classes;
use App\Models\Subjects;
use CodeIgniter\I18n\Time;

class Settings extends BaseController
{
    public function index()
    {
        $session = session();
        if (!$session->get('schid') || !$session->get('regid') || !$session->get('auser') || $session->get('auth') > 2 || $session->get('auth') < 1) {

            return redirect()->to(base_url());
        }
        echo view('admin/include/header');
        echo view('admin/settings/index');
        echo view('admin/include/footer');
    }

    public function subject()
    {
        $session = session();
        if (!$session->get('schid') || !$session->get('regid') || !$session->get('auser') || $session->get('auth') > 2 || $session->get('auth') < 1) {

            return redirect()->to(base_url());
        }
        $staff = new Staf();
        $class = new Classes();
        //
        $request = \Config\Services::request();
        //If there is a post request to this controller
        if ($request->getMethod() == 'post') {

            //validation rules => name should be greater than 3 char
            $rules = [
                'subject' => 'required|min_length[3]'
            ];

            if ($this->validate($rules)) {
                $subject = new Subjects();
                //
                $new_data = [
                    'school_id' => session()->get('schid'),
                    'subject_name' => $request->getVar('subject'),
                    'subject_teacher' => $request->getVar('teacher'),
                    'subject_class' => $request->getVar('class'),
                    'added_on' => new Time('now')
                ];

                if ($subject->save($new_data)) {

                    $session = session();
                    $session->setFlashdata('success', 'Subject (' . $request->getVar('subject') . ') created successfuly.');
                }
            } else {
                $data['validation'] = $this->validator;
            }
        }
        //fetching teachers
        $teachers = $staff->where('schid', session()->get('schid'))
            ->where('safcat', 'Academic Staff')
            ->findAll();

        $classes = $class->where('school_id', session()->get('schid'))
            ->findAll();

        $data = [
            'teachers' => $teachers,
            'classes' => $classes
        ];
        echo view('admin/include/header', $data);
        echo view('admin/settings/create-subject');
        echo view('admin/include/footer');
    }

    public function staff()
    {
        $session = session();
        if (!$session->get('schid') || !$session->get('regid') || !$session->get('auser') || $session->get('auth') > 2 || $session->get('auth') < 1) {

            return redirect()->to(base_url());
        }
        $data = [];
        $request = \Config\Services::request();

        if ($request->getMethod() == 'post') {
            helper(['form', 'text']);

            $staffs = new Staffs();
            $staffID = random_string('alnum', 7);
            //
            $rules = [
                'firstname' => 'required|min_length[3]',
                'lastname' => 'required|min_length[3]',
                'email' => 'required|valid_email',
                'phone' => 'required|min_length[10]|max_length[15]',
                'role' => 'required'
            ];

            if ($this->validate($rules)) {
                //Handle File
                $photo = $request->getFile('passphoto');
                $photo_name = '';
                if ($photo->getSize() > 0) {
                    $photo_name = $photo->getRandomName();
                    $photo->move('./uploads/staffs/SCHOOL001/', $photo_name);
                }

                $staff_info = [
                    'schid' => session()->get('schid'),
                    'staff_id' => $staffID,
                    'fname' => $request->getVar('firstname'),
                    'lname' => $request->getVar('lastname'),
                    'email' => $request->getVar('email'),
                    'phone' => $request->getVar('phone'),
                    'photoURL' => $photo_name,
                    'auth' => $request->getVar('role'),
                    'created_on' => new Time('now')
                ];

                if ($staffs->save($staff_info)) {

                    $session = session();
                    $session->setFlashdata('success', 'Staff created successfully');
                }
            } else {
                $data['validation'] = $this->validator;
            }
        }

        echo view('admin/include/header', $data);
        echo view('admin/settings/create-staff');
        echo view('admin/include/footer');
    }

    public function class()
    {
        $session = session();
        if (!$session->get('schid') || !$session->get('regid') || !$session->get('auser') || $session->get('auth') > 2 || $session->get('auth') < 1) {

            return redirect()->to(base_url());
        }

        $data = [];

        $request = \Config\Services::request();
        if ($request->getMethod() == 'post') {
            helper(['form', 'text']);
            $class = new Classes();
            //validation rules
            $rules = [
                'class' => 'required|min_length[3]'
            ];

            if ($this->validate($rules)) {

                $new_data = [
                    'class_name' => $request->getVar('class'),
                    'school_id' => session()->get('schid'),
                    'added_on' => new Time('now')
                ];

                if ($class->save($new_data)) {

                    $session = session();
                    $session->setFlashdata('success', 'New class (' . $request->getVar('class') . ') created successfuly');
                }
            } else {
                $data['validation'] = $this->validator;
            }
        }

        echo view('admin/include/header', $data);
        echo view('admin/settings/create-class');
        echo view('admin/include/footer');
    }
}
